@@ -2,7 +2,7 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: MittelmannParaCntrl.hpp 1864 2010-12-22 19:21:02Z andreasw $
+// $Id: MittelmannParaCntrl.hpp 2005 2011-06-06 12:55:16Z stefan $
 //
 // Authors:  Andreas Waechter           IBM    2005-10-18
 
@@ -11,6 +11,12 @@
 
 #include "RegisteredTNLP.hpp"
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#else
+#include "configall_system.h"
+#endif
+
 #ifdef HAVE_CMATH
 # include <cmath>
 #else
