@@ -2,13 +2,19 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: solve_problem.cpp 1864 2010-12-22 19:21:02Z andreasw $
+// $Id: solve_problem.cpp 2005 2011-06-06 12:55:16Z stefan $
 //
 // Authors:  Andreas Waechter            IBM    2004-11-05
 
 #include "IpIpoptApplication.hpp"
 #include "RegisteredTNLP.hpp"
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#else
+#include "configall_system.h"
+#endif
+
 #ifdef HAVE_CSTDIO
 # include <cstdio>
 #else
