@@ -1,8 +1,8 @@
-// Copyright (C) 2008, 2009 International Business Machines and others.
+// Copyright (C) 2008, 2011 International Business Machines and others.
 // All Rights Reserved.
-// This code is published under the Common Public License.
+// This code is published under the Eclipse Public License.
 //
-// $Id: IpIterativePardisoSolverInterface.cpp 1702 2010-06-29 13:16:53Z andreasw $
+// $Id: IpIterativePardisoSolverInterface.cpp 2051 2011-09-20 12:39:11Z stefan $
 //
 // Authors:  Andreas Waechter             IBM    2008-09-19
 //
@@ -233,7 +233,7 @@ namespace Ipopt
     delete[] a_;
     a_ = NULL;
 
-#ifndef HAVE_PARDISO_NEWINTERFACE
+#ifdef HAVE_PARDISO_OLDINTERFACE
     THROW_EXCEPTION(OPTION_INVALID, "The inexact version works only with a new version of Pardiso (at least 4.0)");
 #endif
 
@@ -247,10 +247,10 @@ namespace Ipopt
     // Set some parameters for Pardiso
     IPARM_[0] = 1;  // Don't use the default values
 
-#ifdef HAVE_PARDISO_PARALLEL
+#if defined(HAVE_PARDISO_PARALLEL) || ! defined(HAVE_PARDISO)
     // Obtain the numbers of processors from the value of OMP_NUM_THREADS
     char    *var = getenv("OMP_NUM_THREADS");
-    int      num_procs;
+    int      num_procs = 1;
     if (var != NULL) {
       sscanf( var, "%d", &num_procs );
       if (num_procs < 1) {
@@ -261,11 +261,15 @@ namespace Ipopt
       Jnlst().Printf(J_DETAILED, J_LINEAR_ALGEBRA,
                      "Using environment OMP_NUM_THREADS = %d as the number of processors.\n", num_procs);
     }
+#ifdef HAVE_PARDISO
+    // If we run Pardiso through the linear solver loader,
+    // we do not know whether it is the parallel version, so we do not report an error if OMP_NUM_THREADS is not set.
     else {
       Jnlst().Printf(J_ERROR, J_LINEAR_ALGEBRA,
                      "You need to set environment variable OMP_NUM_THREADS to the number of processors used in Pardiso (e.g., 1).\n\n");
       return false;
     }
+#endif
     IPARM_[2] = num_procs;  // Set the number of processors
 #else
 
@@ -471,6 +475,10 @@ namespace Ipopt
     bool just_performed_symbolic_factorization = false;
 
     while (!done) {
+      bool is_normal = false;
+      if (IsNull(InexData().normal_x()) && InexData().compute_normal()) {
+        is_normal = true;
+      }
       if (!have_symbolic_factorization_) {
         if (HaveIpData()) {
           IpData().TimingStats().LinearSystemSymbolicFactorization().Start();
@@ -478,6 +486,29 @@ namespace Ipopt
         PHASE = 11;
         Jnlst().Printf(J_DETAILED, J_LINEAR_ALGEBRA,
                        "Calling Pardiso for symbolic factorization.\n");
+
+        if (is_normal) {
+          DPARM_[ 0] = normal_pardiso_max_iter_;
+          DPARM_[ 1] = normal_pardiso_iter_relative_tol_;
+          DPARM_[ 2] = normal_pardiso_iter_coarse_size_;
+          DPARM_[ 3] = normal_pardiso_iter_max_levels_;
+          DPARM_[ 4] = normal_pardiso_iter_dropping_factor_used_;
+          DPARM_[ 5] = normal_pardiso_iter_dropping_schur_used_;
+          DPARM_[ 6] = normal_pardiso_iter_max_row_fill_;
+          DPARM_[ 7] = normal_pardiso_iter_inverse_norm_factor_;
+        }
+        else {
+          DPARM_[ 0] = pardiso_max_iter_;
+          DPARM_[ 1] = pardiso_iter_relative_tol_;
+          DPARM_[ 2] = pardiso_iter_coarse_size_;
+          DPARM_[ 3] = pardiso_iter_max_levels_;
+          DPARM_[ 4] = pardiso_iter_dropping_factor_used_;
+          DPARM_[ 5] = pardiso_iter_dropping_schur_used_;
+          DPARM_[ 6] = pardiso_iter_max_row_fill_;
+          DPARM_[ 7] = pardiso_iter_inverse_norm_factor_;
+        }
+        DPARM_[ 8] = 25; // maximum number of non-improvement steps
+
         F77_FUNC(pardiso,PARDISO)(PT_, &MAXFCT_, &MNUM_, &MTYPE_,
                                   &PHASE, &N, a_, ia, ja, &PERM,
                                   &NRHS, IPARM_, &MSGLVL_, &B, &X,
@@ -525,10 +556,6 @@ namespace Ipopt
         debug_last_iter_ = 0;
       }
 
-      bool is_normal = false;
-      if (IsNull(InexData().normal_x()) && InexData().compute_normal()) {
-        is_normal = true;
-      }
       if (is_normal) {
         DPARM_[ 0] = normal_pardiso_max_iter_;
         DPARM_[ 1] = normal_pardiso_iter_relative_tol_;
@@ -549,6 +576,7 @@ namespace Ipopt
         DPARM_[ 6] = pardiso_iter_max_row_fill_;
         DPARM_[ 7] = pardiso_iter_inverse_norm_factor_;
       }
+      DPARM_[ 8] = 25; // maximum number of non-improvement steps
 
       F77_FUNC(pardiso,PARDISO)(PT_, &MAXFCT_, &MNUM_, &MTYPE_,
                                 &PHASE, &N, a_, ia, ja, &PERM,
