@@ -1,20 +1,19 @@
-// Copyright (C) 2004, 2010 International Business Machines and others.
+// Copyright (C) 2004, 2011 International Business Machines and others.
 // All Rights Reserved.
-// This code is published under the Common Public License.
+// This code is published under the Eclipse Public License.
 //
-// $Id: IpIpoptAlg.cpp 1692 2010-06-21 19:10:07Z andreasw $
+// $Id: IpIpoptAlg.cpp 2008 2011-06-11 16:23:59Z stefan $
 //
 // Authors:  Carl Laird, Andreas Waechter     IBM    2004-08-13
 
+#include "IpoptConfig.h"
 #include "IpIpoptAlg.hpp"
 #include "IpJournalist.hpp"
 #include "IpRestoPhase.hpp"
 #include "IpOrigIpoptNLP.hpp"
 
-#ifdef HAVE_CONFIG_H
-# include "config_ipopt.h"
-#else
-# define PACKAGE_VERSION IPOPT_VERSION
+#ifdef COIN_HAS_HSL
+#include "CoinHslConfig.h"
 #endif
 
 namespace Ipopt
@@ -263,8 +262,7 @@ namespace Ipopt
     }
 
     if (!isResto) {
-      char vernum[] = PACKAGE_VERSION;
-      Jnlst().Printf(J_ITERSUMMARY, J_MAIN, "This is Ipopt version %s, running with linear solver %s.\n\n", vernum, linear_solver_.c_str());
+      Jnlst().Printf(J_ITERSUMMARY, J_MAIN, "This is Ipopt version "IPOPT_VERSION", running with linear solver %s.\n\n", linear_solver_.c_str());
     }
 
     SolverReturn retval = UNASSIGNED;
@@ -948,17 +946,19 @@ namespace Ipopt
     jnlst.Printf(J_INSUPPRESSIBLE, J_MAIN,
                  "\n******************************************************************************\n"
                  "This program contains Ipopt, a library for large-scale nonlinear optimization.\n"
-                 " Ipopt is released as open source code under the Common Public License (CPL).\n"
+                 " Ipopt is released as open source code under the Eclipse Public License (EPL).\n"
                  "         For more information visit http://projects.coin-or.org/Ipopt\n"
                  "******************************************************************************\n\n");
 #ifdef COIN_HAS_MUMPS
-# ifndef HAVE_MA27
-#  ifndef HAVE_MA57
-#   ifndef HAVE_PARDISO
-#    ifndef HAVE_WSMP
+# ifndef COINHSL_HAS_MA27
+#  ifndef COINHSL_HAS_MA57
+#   ifndef COINHSL_HAS_MA86
+#    ifndef HAVE_PARDISO
+#     ifndef HAVE_WSMP
     jnlst.Printf(J_INSUPPRESSIBLE, J_MAIN,
                  "NOTE: You are using Ipopt by default with the MUMPS linear solver.\n"
                  "      Other linear solvers might be more efficient (see Ipopt documentation).\n\n\n");
+#     endif
 #    endif
 #   endif
 #  endif
