@@ -2,11 +2,14 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpNLPScaling.cpp 1864 2010-12-22 19:21:02Z andreasw $
+// $Id: IpNLPScaling.cpp 2051 2011-09-20 12:39:11Z stefan $
 //
 // Authors:  Carl Laird, Andreas Waechter     IBM    2005-06-25
 
 #include "IpNLPScaling.hpp"
+#include "IpSymMatrix.hpp"
+#include "IpScaledMatrix.hpp"
+#include "IpSymScaledMatrix.hpp"
 
 namespace Ipopt
 {
@@ -15,6 +18,12 @@ namespace Ipopt
   static const Index dbg_verbosity = 0;
 #endif
 
+  NLPScalingObject::NLPScalingObject()
+  {}
+
+  NLPScalingObject::~NLPScalingObject()
+  {}
+
   SmartPtr<Vector> NLPScalingObject::apply_vector_scaling_x_LU_NonConst(
     const Matrix& Px_LU,
     const SmartPtr<const Vector>& lu,
@@ -189,6 +198,12 @@ namespace Ipopt
     }
   }
 
+  StandardScalingBase::StandardScalingBase()
+  {}
+
+  StandardScalingBase::~StandardScalingBase()
+  {}
+
   void
   StandardScalingBase::RegisterOptions(SmartPtr<RegisteredOptions> roptions)
   {
