@@ -2,7 +2,7 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpPardisoSolverInterface.cpp 1864 2010-12-22 19:21:02Z andreasw $
+// $Id: IpPardisoSolverInterface.cpp 2020 2011-06-16 20:46:16Z andreasw $
 //
 // Authors:  Carl Laird, Andreas Waechter     IBM    2005-03-17
 //
@@ -57,7 +57,7 @@
 /* Prototypes for Pardiso's subroutines */
 extern "C"
 {
-#ifndef HAVE_PARDISO_NEWINTERFACE
+#ifdef HAVE_PARDISO_OLDINTERFACE
   void PARDISOINIT_FUNC(void* PT, const ipfint* MTYPE, ipfint* IPARM);
 #else
   // The following is a fix to allow linking with Pardiso library under Windows
@@ -219,7 +219,7 @@ namespace Ipopt
     roptions->AddLowerBoundedIntegerOption(
       "pardiso_iter_max_levels",
       "Maximum Size of Grid Levels",
-      1, 10000,
+      1, 10,
       "DPARM(4)");
     roptions->AddBoundedNumberOption(
       "pardiso_iter_dropping_factor",
@@ -345,9 +345,9 @@ namespace Ipopt
     // Call Pardiso's initialization routine
     IPARM_[0] = 0;  // Tell it to fill IPARM with default values(?)
 
-#ifdef HAVE_PARDISO_NEWINTERFACE
+#ifndef HAVE_PARDISO_OLDINTERFACE
     ipfint ERROR = 0;
-    ipfint SOLVER = 0; // initialze only direct solver
+    ipfint SOLVER = 0; // initialize only direct solver
 
     PARDISOINIT_FUNC(PT_, &MTYPE_, &SOLVER, IPARM_, DPARM_, &ERROR);
 #else
@@ -357,10 +357,10 @@ namespace Ipopt
     // Set some parameters for Pardiso
     IPARM_[0] = 1;  // Don't use the default values
 
-#ifdef HAVE_PARDISO_PARALLEL
+#if defined(HAVE_PARDISO_PARALLEL) || ! defined(HAVE_PARDISO)
     // Obtain the numbers of processors from the value of OMP_NUM_THREADS
     char    *var = getenv("OMP_NUM_THREADS");
-    int      num_procs;
+    int      num_procs = 1;
     if (var != NULL) {
       sscanf( var, "%d", &num_procs );
       if (num_procs < 1) {
@@ -371,14 +371,18 @@ namespace Ipopt
       Jnlst().Printf(J_DETAILED, J_LINEAR_ALGEBRA,
                      "Using environment OMP_NUM_THREADS = %d as the number of processors.\n", num_procs);
     }
+#ifdef HAVE_PARDISO
+    // If we run Pardiso through the linear solver loader,
+    // we do not know whether it is the parallel version, so we do not report an error if OMP_NUM_THREADS is not set.
     else {
       Jnlst().Printf(J_ERROR, J_LINEAR_ALGEBRA,
                      "You need to set environment variable OMP_NUM_THREADS to the number of processors used in Pardiso (e.g., 1).\n\n");
       return false;
     }
+#endif
     IPARM_[2] = num_procs;  // Set the number of processors
-#else
 
+#else
     IPARM_[2] = 1;
 #endif
 
@@ -402,11 +406,11 @@ namespace Ipopt
     IPARM_[23] = 1; // parallel fac
     IPARM_[24] = 1; // parallel solve
     IPARM_[28] = 0; // 32-bit factorization
-    IPARM_[29] = 1; // we need this for IPOPT interface
-    IPARM_[29] = 1; // we need this for IPOPT interface
+    IPARM_[29] = 1; //we need this for IPOPT interface
+    //IPARM_[33] = 1; // bit-by-bit identical results in parallel run
 
     if (pardiso_iterative_) {
-#ifndef HAVE_PARDISO_NEWINTERFACE
+#ifdef HAVE_PARDISO_OLDINTERFACE
       THROW_EXCEPTION(OPTION_INVALID,
                       "You chose to use the iterative version of Pardiso, but you need to use a Pardiso version of at least 4.0.");
 #endif
@@ -720,11 +724,9 @@ namespace Ipopt
       }
 
 #ifdef PARDISO_MATCHING_PREPROCESS
-      {
-        ipfint* tmp2_  = new ipfint[N];
-        smat_reordering_pardiso_wsmp_ (&N, ia, ja, a_, ia2, ja2, a2_, perm2, scale2, tmp2_, 1);
-        delete[] tmp2_;
-      }
+      ipfint* tmp3_  = new ipfint[N];
+      smat_reordering_pardiso_wsmp_ (&N, ia, ja, a_, ia2, ja2, a2_, perm2, scale2, tmp3_, 1);
+      delete[] tmp3_;
 #endif
 
       PARDISO_FUNC(PT_, &MAXFCT_, &MNUM_, &MTYPE_,
