@@ -2,15 +2,13 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: AmplTNLP.cpp 1864 2010-12-22 19:21:02Z andreasw $
+// $Id: AmplTNLP.cpp 2020 2011-06-16 20:46:16Z andreasw $
 //
 // Authors:  Carl Laird, Andreas Waechter     IBM    2004-08-13
 
 #include "IpoptConfig.h"
-#ifdef HAVE_CONFIG_H
-# include "config_ipopt.h"
-#else
-# define PACKAGE_VERSION IPOPT_VERSION
+#ifndef PACKAGE_VERSION
+#define PACKAGE_VERSION IPOPT_VERSION
 #endif
 
 #include "AmplTNLP.hpp"
@@ -19,6 +17,16 @@
 #include "IpSymTMatrix.hpp"
 #include "IpBlas.hpp"
 
+#ifdef HAVE_CSTRING
+# include <cstring>
+#else
+# ifdef HAVE_STRING_H
+#  include <string.h>
+# else
+#  error "don't have header file for string"
+# endif
+#endif
+
 /* AMPL includes */
 #include "asl.h"
 #include "asl_pfgh.h"
@@ -947,6 +955,18 @@ namespace Ipopt
     }
   }
 
+
+  AmplOptionsList::AmplOption::AmplOption(const std::string ipopt_option_name,
+                                          AmplOptionType type,
+                                          const std::string description)
+      :
+      ipopt_option_name_(ipopt_option_name),
+      type_(type)
+  {
+    description_ = new char[description.size()+1];
+    strcpy(description_, description.c_str());
+  }
+
   AmplOptionsList::~AmplOptionsList()
   {
     if (keywds_) {
@@ -1280,6 +1300,10 @@ namespace Ipopt
                                      "ma57_pivtolmax",
                                      AmplOptionsList::Number_Option,
                                      "Maximal pivot tolerance for the linear solver MA57");
+    ampl_options_list->AddAmplOption("ma57_pivot_order",
+                                     "ma57_pivot_order",
+                                     AmplOptionsList::Integer_Option,
+                                     "Controls pivot order in MA57");
 
     ampl_options_list->AddAmplOption("pardiso_matching_strategy",
                                      "pardiso_matching_strategy",
