@@ -2,13 +2,15 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpTypes.hpp 1864 2010-12-22 19:21:02Z andreasw $
+// $Id: IpTypes.hpp 2005 2011-06-06 12:55:16Z stefan $
 //
 // Authors:  Carl Laird, Andreas Waechter     IBM    2004-08-13
 
 #ifndef __IPTYPES_HPP__
 #define __IPTYPES_HPP__
 
+#include "IpoptConfig.h"
+
 namespace Ipopt
 {
   /** Type of all numbers */
@@ -20,4 +22,7 @@ namespace Ipopt
 
 } // namespace Ipopt
 
+/* Type of Fortran integer translated into C */
+typedef FORTRAN_INTEGER_TYPE ipfint;
+
 #endif
