@@ -1,8 +1,8 @@
-/* Copyright (C) 2008 GAMS Development and others
+/* Copyright (C) 2008, 2011 GAMS Development and others
  All Rights Reserved.
  This code is published under the Eclipse Public License.
 
- $Id: HSLLoader.c 1864 2010-12-22 19:21:02Z andreasw $
+ $Id: HSLLoader.c 2049 2011-09-20 09:58:03Z stefan $
 
  Author: Stefan Vigerske
 */
@@ -11,12 +11,20 @@
 #include "LibraryHandler.h"
 #include "HSLLoader.h"
 
+#ifdef COIN_HAS_HSL
+#include "CoinHslConfig.h"
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
+#include "hsl_ma86d.h"
 
 #define HSLLIBNAME "libhsl." SHAREDLIBEXT
 
-soHandle_t HSL_handle=NULL;
+/* Type of Fortran integer translated into C */
+typedef FORTRAN_INTEGER_TYPE ipfint;
+
+static soHandle_t HSL_handle=NULL;
 
 void LSL_lateHSLLoad();
 
@@ -106,18 +114,36 @@ typedef void (*ma57ed_t) (
 
 typedef void (*mc19ad_t)(ipfint *N, ipfint *NZ, double* A, ipfint *IRN, ipfint* ICN, float* R, float* C, float* W);
 
+typedef void (*ma86_default_control_t)(struct ma86_control *control);
+typedef void (*ma86_analyse_t)(const int n, const int ptr[], const int row[],
+   int order[], void **keep, const struct ma86_control *control,
+   struct ma86_info *info);
+typedef void (*ma86_factor_t)(const int n, const int ptr[], const int row[],
+   const ma86pkgtype_d_ val[], const int order[], void **keep,
+   const struct ma86_control *control, struct ma86_info *info,
+   const ma86pkgtype_d_ scale[]);
+typedef void (*ma86_factor_solve_t)(const int n, const int ptr[],
+   const int row[], const ma86pkgtype_d_ val[], const int order[], void **keep,
+   const struct ma86_control *control, struct ma86_info *info, const int nrhs,
+   const int ldx, ma86pkgtype_d_ x[], const ma86pkgtype_d_ scale[]);
+typedef void (*ma86_solve_t)(const int job, const int nrhs, const int ldx,
+   ma86pkgtype_d_ *x, const int order[], void **keep,
+   const struct ma86_control *control, struct ma86_info *info,
+   const ma86pkgtype_d_ scale[]);
+typedef void (*ma86_finalise_t)(void **keep,
+   const struct ma86_control *control);
 
-#ifndef HAVE_MA27
-ma27id_t func_ma27id=NULL;
-ma27ad_t func_ma27ad=NULL;
-ma27bd_t func_ma27bd=NULL;
-ma27cd_t func_ma27cd=NULL;
+#ifndef COINHSL_HAS_MA27
+static ma27id_t func_ma27id=NULL;
+static ma27ad_t func_ma27ad=NULL;
+static ma27bd_t func_ma27bd=NULL;
+static ma27cd_t func_ma27cd=NULL;
 
 void F77_FUNC(ma27id,MA27ID)(ipfint* ICNTL, double* CNTL)
 {
   if (func_ma27id==NULL) LSL_lateHSLLoad();
   if (func_ma27id==NULL) {
-    fprintf(stderr, "HSL routine MA27AD not found in " HSLLIBNAME ".\nAbort...\n");
+    fprintf(stderr, "HSL routine MA27ID not found in " HSLLIBNAME ".\nAbort...\n");
     exit(EXIT_FAILURE);
   }
   func_ma27id(ICNTL, CNTL);
@@ -162,9 +188,9 @@ void F77_FUNC(ma27cd,MA27CD)(ipfint *N, double* A, ipfint* LA, ipfint* IW,
 
 #endif
 
-#ifndef HAVE_MA28
+#ifndef COINHSL_HAS_MA28
 
-ma28ad_t func_ma28ad=NULL;
+static ma28ad_t func_ma28ad=NULL;
 
 void F77_FUNC(ma28ad,MA28AD)(void* nsize, void* nz, void* rw, void* licn, void* iw,
 		                         void* lirn, void* iw2, void* pivtol, void* iw3, void* iw4, void* rw2, void* iflag) {
@@ -177,13 +203,13 @@ void F77_FUNC(ma28ad,MA28AD)(void* nsize, void* nz, void* rw, void* licn, void*
 }
 #endif
 
-#ifndef HAVE_MA57
+#ifndef COINHSL_HAS_MA57
 
-ma57id_t func_ma57id=NULL;
-ma57ad_t func_ma57ad=NULL;
-ma57bd_t func_ma57bd=NULL;
-ma57cd_t func_ma57cd=NULL;
-ma57ed_t func_ma57ed=NULL;
+static ma57id_t func_ma57id=NULL;
+static ma57ad_t func_ma57ad=NULL;
+static ma57bd_t func_ma57bd=NULL;
+static ma57cd_t func_ma57cd=NULL;
+static ma57ed_t func_ma57ed=NULL;
 
 void  F77_FUNC (ma57id, MA57ID) (double    *cntl,  ipfint    *icntl) {
   if (func_ma57id==NULL) LSL_lateHSLLoad();
@@ -281,9 +307,84 @@ void  F77_FUNC (ma57ed, MA57ED) (
 }
 #endif
 
-#ifndef HAVE_MC19
+#ifndef COINHSL_HAS_MA86
 
-mc19ad_t func_mc19ad=NULL;
+static ma86_default_control_t func_ma86_default_control=NULL;
+static ma86_analyse_t func_ma86_analyse=NULL;
+static ma86_factor_t func_ma86_factor=NULL;
+static ma86_factor_solve_t func_ma86_factor_solve=NULL;
+static ma86_solve_t func_ma86_solve=NULL;
+static ma86_finalise_t func_ma86_finalise=NULL;
+
+void ma86_default_control(struct ma86_control *control) {
+  if (func_ma86_default_control==NULL) LSL_lateHSLLoad();
+  if (func_ma86_default_control==NULL) {
+    fprintf(stderr, "HSL routine ma86_default_control not found in " HSLLIBNAME ".\nAbort...\n");
+    exit(EXIT_FAILURE);
+  }
+  func_ma86_default_control(control);
+}
+
+void ma86_analyse(const int n, const int ptr[], const int row[], int order[],
+      void **keep, const struct ma86_control *control, struct ma86_info *info) {
+  if (func_ma86_analyse==NULL) LSL_lateHSLLoad();
+  if (func_ma86_analyse==NULL) {
+    fprintf(stderr, "HSL routine ma86_analyse not found in " HSLLIBNAME ".\nAbort...\n");
+    exit(EXIT_FAILURE);
+  }
+  func_ma86_analyse(n, ptr, row, order, keep, control, info);
+}
+
+void ma86_factor(const int n, const int ptr[], const int row[],
+      const ma86pkgtype_d_ val[], const int order[], void **keep,
+      const struct ma86_control *control, struct ma86_info *info,
+      const ma86pkgtype_d_ scale[]) {
+  if (func_ma86_factor==NULL) LSL_lateHSLLoad();
+  if (func_ma86_factor==NULL) {
+    fprintf(stderr, "HSL routine ma86_factor not found in " HSLLIBNAME ".\nAbort...\n");
+    exit(EXIT_FAILURE);
+  }
+  func_ma86_factor(n, ptr, row, val, order, keep, control, info, scale);
+}
+
+void ma86_factor_solve(const int n, const int ptr[], const int row[],
+      const ma86pkgtype_d_ val[], const int order[], void **keep,
+      const struct ma86_control *control, struct ma86_info *info,
+      const int nrhs, const int ldx, ma86pkgtype_d_ x[],
+      const ma86pkgtype_d_ scale[]) {
+  if (func_ma86_factor_solve==NULL) LSL_lateHSLLoad();
+  if (func_ma86_factor_solve==NULL) {
+    fprintf(stderr, "HSL routine ma86_factor_solve not found in " HSLLIBNAME ".\nAbort...\n");
+    exit(EXIT_FAILURE);
+  }
+  func_ma86_factor_solve(n, ptr, row, val, order, keep, control, info, nrhs,
+      ldx, x, scale);
+}
+
+void ma86_solve(const int job, const int nrhs, const int ldx, ma86pkgtype_d_ *x,
+      const int order[], void **keep, const struct ma86_control *control,
+      struct ma86_info *info, const ma86pkgtype_d_ scale[]) {
+  if (func_ma86_solve==NULL) LSL_lateHSLLoad();
+  if (func_ma86_solve==NULL) {
+    fprintf(stderr, "HSL routine ma86_solve not found in " HSLLIBNAME ".\nAbort...\n");
+    exit(EXIT_FAILURE);
+  }
+  func_ma86_solve(job, nrhs, ldx, x, order, keep, control, info, scale);
+}
+
+void ma86_finalise(void **keep, const struct ma86_control *control) {
+  if (func_ma86_finalise==NULL) LSL_lateHSLLoad();
+  if (func_ma86_finalise==NULL) {
+    fprintf(stderr, "HSL routine ma86_finalise not found in " HSLLIBNAME ".\nAbort...\n");
+    exit(EXIT_FAILURE);
+  }
+  func_ma86_finalise(keep, control);
+}
+#endif
+
+#ifndef COINHSL_HAS_MC19
+
+static mc19ad_t func_mc19ad=NULL;
 
 void F77_FUNC(mc19ad,MC19AD)(ipfint *N, ipfint *NZ, double* A, ipfint *IRN,
                              ipfint* ICN, float* R, float* C, float* W) {
@@ -307,18 +408,18 @@ int LSL_loadHSL(const char* libname, char* msgbuf, int msglen) {
     return 1;
 	
   /* load HSL functions */
-#ifndef HAVE_MA27
+#ifndef COINHSL_HAS_MA27
   func_ma27id=(ma27id_t)LSL_loadSym(HSL_handle, "ma27id", msgbuf, msglen);
   func_ma27ad=(ma27ad_t)LSL_loadSym(HSL_handle, "ma27ad", msgbuf, msglen);
   func_ma27bd=(ma27bd_t)LSL_loadSym(HSL_handle, "ma27bd", msgbuf, msglen);
   func_ma27cd=(ma27cd_t)LSL_loadSym(HSL_handle, "ma27cd", msgbuf, msglen);
 #endif
 
-#ifndef HAVE_MA28
+#ifndef COINHSL_HAS_MA28
   func_ma28ad=(ma28ad_t)LSL_loadSym(HSL_handle, "ma28ad", msgbuf, msglen);
 #endif
 
-#ifndef HAVE_MA57
+#ifndef COINHSL_HAS_MA57
   func_ma57id=(ma57id_t)LSL_loadSym(HSL_handle, "ma57id", msgbuf, msglen);
   func_ma57ad=(ma57ad_t)LSL_loadSym(HSL_handle, "ma57ad", msgbuf, msglen);
   func_ma57bd=(ma57bd_t)LSL_loadSym(HSL_handle, "ma57bd", msgbuf, msglen);
@@ -326,7 +427,16 @@ int LSL_loadHSL(const char* libname, char* msgbuf, int msglen) {
   func_ma57ed=(ma57ed_t)LSL_loadSym(HSL_handle, "ma57ed", msgbuf, msglen);
 #endif
 
-#ifndef HAVE_MC19
+#ifndef COINHSL_HAS_MA86
+  func_ma86_default_control=(ma86_default_control_t)LSL_loadSym(HSL_handle, "ma86_default_control_d", msgbuf, msglen);
+  func_ma86_analyse=(ma86_analyse_t)LSL_loadSym(HSL_handle, "ma86_analyse_d", msgbuf, msglen);
+  func_ma86_factor=(ma86_factor_t)LSL_loadSym(HSL_handle, "ma86_factor_d", msgbuf, msglen);
+  func_ma86_factor_solve=(ma86_factor_solve_t)LSL_loadSym(HSL_handle, "ma86_factor_solve_d", msgbuf, msglen);
+  func_ma86_solve=(ma86_solve_t)LSL_loadSym(HSL_handle, "ma86_solve_d", msgbuf, msglen);
+  func_ma86_finalise=(ma86_finalise_t)LSL_loadSym(HSL_handle, "ma86_finalise_d", msgbuf, msglen);
+#endif
+
+#ifndef COINHSL_HAS_MC19
   func_mc19ad=(mc19ad_t)LSL_loadSym(HSL_handle, "mc19ad", msgbuf, msglen);
 #endif
 
@@ -342,18 +452,18 @@ int LSL_unloadHSL() {
   rc = LSL_unloadLib(HSL_handle);
   HSL_handle=NULL;
 	
-#ifndef HAVE_MA27
+#ifndef COINHSL_HAS_MA27
   func_ma27id=NULL;
   func_ma27ad=NULL;
   func_ma27bd=NULL;
   func_ma27cd=NULL;
 #endif
 
-#ifndef HAVE_MA28
+#ifndef COINHSL_HAS_MA28
   func_ma28ad=NULL;
 #endif
 
-#ifndef HAVE_MA57
+#ifndef COINHSL_HAS_MA57
   func_ma57id=NULL;
   func_ma57ad=NULL;
   func_ma57bd=NULL;
@@ -361,7 +471,16 @@ int LSL_unloadHSL() {
   func_ma57ed=NULL;
 #endif
 
-#ifndef HAVE_MC19
+#ifndef COINHSL_HAS_MA86
+  func_ma86_default_control=NULL;
+  func_ma86_analyse=NULL;
+  func_ma86_factor=NULL;
+  func_ma86_factor_solve=NULL;
+  func_ma86_solve=NULL;
+  func_ma86_finalise=NULL;
+#endif
+
+#ifndef COINHSL_HAS_MC19
   func_mc19ad=NULL;
 #endif
 
@@ -373,7 +492,7 @@ int LSL_isHSLLoaded() {
 }
 
 int LSL_isMA27available() {
-#ifndef HAVE_MA27
+#ifndef COINHSL_HAS_MA27
 	return HSL_handle!=NULL && func_ma27id!=NULL && func_ma27ad!=NULL && func_ma27bd!=NULL && func_ma27cd!=NULL;
 #else
 	return 0;
@@ -381,7 +500,7 @@ int LSL_isMA27available() {
 }
 
 int LSL_isMA28available() {
-#ifndef HAVE_MA28
+#ifndef COINHSL_HAS_MA28
 	return HSL_handle!=NULL && func_ma28ad!=NULL;
 #else
 	return 0;
@@ -389,15 +508,24 @@ int LSL_isMA28available() {
 }
 
 int LSL_isMA57available() {
-#ifndef HAVE_MA57
+#ifndef COINHSL_HAS_MA57
 	return HSL_handle!=NULL && func_ma57id!=NULL && func_ma57ad!=NULL && func_ma57bd!=NULL && func_ma57cd!=NULL && func_ma57ed!=NULL;
 #else
 	return 0;
 #endif
 }
 
+int LSL_isMA86available() {
+#ifndef COINHSL_HAS_MA86
+	return HSL_handle!=NULL && func_ma86_default_control!=NULL && func_ma86_analyse!=NULL && func_ma86_factor!=NULL && func_ma86_factor_solve!=NULL && func_ma86_solve!=NULL && func_ma86_finalise!=NULL;
+#else
+	return 0;
+#endif
+}
+
+
 int LSL_isMC19available() {
-#ifndef HAVE_MC19
+#ifndef COINHSL_HAS_MC19
 	return HSL_handle!=NULL && func_mc19ad!=NULL;
 #else
 	return 0;
